let programs = {}
const days = ['ראשון', 'שני', 'שלישי', 'רביעי', 'חמישי', 'שישי', 'שבת']

const ZOOM_DATES = [[22, 5], [3, 6], [10, 6], [17, 6], [24, 6], [1, 7], [8, 7], [15, 7]]
const ZOOM_TIMES_INTERVAL = 10
const ZOOM_TIMES_MIN_MAX = [10, 12]
const ZOOM_MEETINGS_PER_HOUR = 3
const ZOOM_MEETINGS_PER_DAY = 36;

const PHYSICAL_DATES = [[22, 5], [4, 6], [18, 6], [25, 6], [2, 7], [9, 7], [16, 7]]
const PHYSICAL_TIMES_INTERVAL = 30
const PHYSICAL_TIMES_MIN_MAX = [10, 14]
const PHYSICAL_MEETINGS_PER_HOUR = 6
const PHYSICAL_MEETINGS_PER_DAY = 48;

const DISABLED_ZOOM_DATES = [[4, 3], [11, 3]];
const DISABLED_PHYSICAL_DATES = [[5, 3], [12, 3]];

let current_dates = ZOOM_DATES
let current_interval = ZOOM_TIMES_INTERVAL
let current_min_max = ZOOM_TIMES_MIN_MAX
let current_meetings_per_hour = ZOOM_MEETINGS_PER_HOUR
let current_meetings_per_day = ZOOM_MEETINGS_PER_DAY

function isDateDisabled(day, month, disabledDates) {
    return disabledDates.some(d => d[0] === day && d[1] === month);
}

function hideAll() {
    $('#meetingDate').parent().hide();
    $('#meetingTime').parent().hide();
    $('#degreeSelect').parent().show();
    // $('#fieldSelect').parent().hide();
    $('#programSelect').parent().hide();
}
function showPhysical() {
    current_dates = PHYSICAL_DATES
    current_interval = PHYSICAL_TIMES_INTERVAL
    current_min_max = PHYSICAL_TIMES_MIN_MAX
    current_meetings_per_hour = PHYSICAL_MEETINGS_PER_HOUR
    current_meetings_per_day = PHYSICAL_MEETINGS_PER_DAY
    $('#meetingDate').parent().show();
    $('#meetingTime').parent().hide();
    $('#degreeSelect').removeAttr('required')
    //$('#fieldSelect').removeAttr('required')
    //$('#programSelect').removeAttr('required')
    $('#fieldSelect').closest('fieldset').hide(); // Hide the fieldset containing the fieldSelect dropdown
    $('#programSelect').closest('fieldset').hide(); // Hide the fieldset containing the programSelect dropdown
}
function showPhone() {
    $('#fieldSelect').parent().show();
    $('#programSelect').parent().show();
    $('#degreeSelect').parent().show();
    $('#meetingDate').removeAttr('required')
    $('#meetingTime').removeAttr('required')
	$('#myform').attr('action','https://www.leadock.com/pages/formHandler');
    // $('#degreeSelect option[value="1"]').show();
}
function showZoom() {
    current_dates = ZOOM_DATES
    current_interval = ZOOM_TIMES_INTERVAL
    current_min_max = ZOOM_TIMES_MIN_MAX
    current_meetings_per_hour = ZOOM_MEETINGS_PER_HOUR
    current_meetings_per_day = ZOOM_MEETINGS_PER_DAY
    $('#meetingDate').parent().show();
    $('#meetingTime').parent().hide();
    $('#fieldSelect').parent().show();
    $('#programSelect').parent().show();
    // $('#degreeSelect option[value="1"]').hide();
}

function addZero(a) {
    return a < 10 ? `0${a}` : a;
}
function populateDates(dates) {
	let disabledDates;
	if (current_dates === ZOOM_DATES) {
        disabledDates = DISABLED_ZOOM_DATES;
    } else {
        disabledDates = DISABLED_PHYSICAL_DATES;
    }
    if (meetingData.length <= 0) {
        var parsedData = {};
    } else {
        var parsedData = JSON.parse(meetingData);
    }
    
    $("#meetingDate").empty().append($('<option>', {
        value: '',
        text: 'תאריך מפגש:',
    }));

    var newData = {}
    for (let [date, times] of Object.entries(parsedData)) {
        if (!newData[date])
            newData[date] = 0
        for (let count of Object.values(times))
            newData[date] += count
    }
    for (let [day, month] of dates) {
        const d = new Date(2024, month - 1, day, current_min_max[0])
        const dateString = `${d.getDate()}.${d.getMonth() + 1}.${d.getFullYear() - 2000}`
        const isDisabled = newData[dateString] >= current_meetings_per_day || isDateDisabled(day, month, disabledDates);
        $("#meetingDate").append($('<option>', {
            value: dateString,
            text: `יום ${days[d.getDay()]} ה- ${d.getDate()}.${d.getMonth() + 1}.${d.getFullYear() - 2000}`,
            disabled: isDisabled
        }));
    }
}
function populateTimes(interval, selectedDate, meetingData) {
    if (meetingData.length <= 0) {
        var parsedData = undefined;
    } else {
        var parsedData = JSON.parse(meetingData);
    }

    $("#meetingTime").empty().append($('<option>', {
        value: '',
        text: 'שעת מפגש:',
    }));

    for (let i = current_min_max[0]; i < current_min_max[1]; i++) {
        for (let j = 0; j < 60; j += interval) {
            const d = new Date(2024, 1, 1, i, j, 0);
            let end = new Date(d);
            end.setMinutes(end.getMinutes() + interval);

            // Construct the time string with flipped hours for display
            const timeDisplay = `${end.getHours()}:${addZero(end.getMinutes())}-${d.getHours()}:${addZero(d.getMinutes())}`;

            // Construct the value string with flipped times for backend processing
            const timeValue = `${end.getHours()}:${addZero(end.getMinutes())}-${d.getHours()}:${addZero(d.getMinutes())}`;

            // Check if the current time slot has available spots
            const availableSpots = current_meetings_per_hour - (parsedData && parsedData[selectedDate] && parsedData[selectedDate][timeValue] ? parsedData[selectedDate][timeValue] : 0);

            if (availableSpots > 0) {
                $("#meetingTime").append($('<option>', {
                    value: timeValue,
                    text: timeDisplay,
                }));
            }
        }
    }
}

function populateSelect(selectId, options, selected = '') {
    const select = $(selectId);
    // Remove all options except the first one
    select.find('option:not(:first)').remove();
    Object.entries(options).forEach(([key, value]) => {
        select.append($('<option>', {
            value: key,
            text: value.label
        }));
    });
    select.val(selected).trigger('change');
    if (selected != '')
        select.parent().hide();
}

function onChangeDegree() {
    var selectedValue = $('#degreeSelect').val();
    $('#fieldSelect').parent().hide();
    $('#programSelect').parent().hide();

    if (selectedValue) {
        if (programs[selectedValue] && programs[selectedValue].childs) {
            populateSelect('#fieldSelect', programs[selectedValue].childs);
            $('#fieldSelect').parent().show();
            $('input[name="268"]').val(programs[selectedValue]['label']);
            $('input[name="269"]').val(selectedValue);
        }
    }
    $('#programSelect').parent().hide();
}
function onChangeField() {
    var degreeSelectValue = $('#degreeSelect').val();
    var selectedValue = $(this).val();
    $('#programSelect').parent().hide();
    if (degreeSelectValue && selectedValue) {
        if (programs[degreeSelectValue].childs[selectedValue] && programs[degreeSelectValue].childs[selectedValue].childs) {
            populateSelect('#programSelect', programs[degreeSelectValue].childs[selectedValue].childs);
            $('#programSelect').parent().show();
            $('input[name="270"]').val(programs[degreeSelectValue].childs[selectedValue]['label']);
            $('input[name="271"]').val(programs[degreeSelectValue].childs[selectedValue]['value']);
        }
    }
}
function onChangeProgram() {
    var degreeSelectValue = $('#degreeSelect').val();
    var fieldSelectValue = $('#fieldSelect').val();
    var selectedValue = $(this).val();
    if (selectedValue) {
        var field_value = programs[degreeSelectValue].childs[fieldSelectValue].childs[selectedValue];
        if (programs[degreeSelectValue].childs[fieldSelectValue].childs[selectedValue]) {
            $('input[name="272"]').val(field_value['label']);
            $('input[name="273"]').val(field_value['value']);
        }
    }
}
async function onChangeMain() {
    programs = await $.getJSON('data/programs.json');
    // Show the form and hide the mainSelect dropdown
    $('#myform').show();
    const mainSelect = $(this);
    mainSelect.closest('fieldset').hide(); // Adjust this if mainSelect is not within a fieldset
    const selected = mainSelect.val();
    // Show the "change selection" button
    $('#changeSelection').show();

    hideAll();
    // Logic for showing fields based on selection
    if (selected === 'phone_advice') {
        showPhone();
        populateSelect('#degreeSelect', programs, '');
        $('#fieldSelect').closest('fieldset').removeClass('hidden-fieldset');
        $('#programSelect').closest('fieldset').removeClass('hidden-fieldset');
    } else {
        if (selected === 'zoom_meeting') {
            showZoom();
            $('#fieldSelect').closest('fieldset').removeClass('hidden-fieldset');
            $('#programSelect').closest('fieldset').removeClass('hidden-fieldset');
        } else {
            showPhysical();
            //$('#fieldSelect').closest('fieldset').addClass('hidden-fieldset');
            //$('#programSelect').closest('fieldset').addClass('hidden-fieldset');
        }
        $('#meetingDate').prop('required', true)
        $('#meetingTime').prop('required', true)
        populateSelect('#degreeSelect', programs, 1);
        onChangeDegree();
        populateDates(current_dates);
    }
}
$(document).ready(function () {
    hideAll();
    $('#degreeSelect').change(onChangeDegree);
    $('#fieldSelect').change(onChangeField);
    $('#programSelect').change(onChangeProgram);
    $('#mainSelect').change(onChangeMain);

    $('#meetingDate').change(function () {
        $('#meetingTime').parent().show();
        var selectedDate = $(this).val();
        populateTimes(current_interval, selectedDate, meetingData)
    });
    $('#changeSelection').click(function () {
        location.reload();
    });
});



setInterval(function () {
    document.getElementById("field_281").value = document.getElementById("meetingDate").value;
    document.getElementById("field_282").value = document.getElementById("meetingTime").value;;
    document.getElementById("field_283").value = document.getElementById("mainSelect").value;;
}, 100);
